@@ -18,7 +18,10 @@ my $cert_path = '/etc/ssl/uacme/' . $fqdn . '/cert.pem';
 my $x509;
 eval {
 	$x509 = Crypt::OpenSSL::X509->new_from_file($cert_path);
-} or die("$cert_path: $!");
+} or do {
+	print('{"subject_alt_names": []}' . "\n");
+	exit(0);
+};
 
 my $names = $x509->subjectaltname();
 print('{ "subject_alt_names": [');
